@@ -289,10 +289,17 @@ schemes = {
     },
     'Gravatar': {
         'flags': ['gravatar.com\\/avatar', 'thumbnailUrl'],
+        'url_mutations': [
+            {
+                'from': r'https?://.*?gravatar.com/(?P<username>[^/]+)',
+                'to': 'https://en.gravatar.com/{username}.json',
+            }
+        ],
         'regex': r'^(.+?)$',
         'extract_json': True,
         'fields': {
             'gravatar_id': lambda x: x['entry'][0]['id'],
+            'image': lambda x: x['entry'][0]['thumbnailUrl'],
             'username': lambda x: x['entry'][0]['preferredUsername'],
             'fullname': lambda x: x['entry'][0].get('name', {}).get('formatted'),
             'name': lambda x: x['entry'][0]['displayName'],
@@ -616,6 +623,7 @@ schemes = {
         'extract_json': True,
         'url_mutations': [
             {
+                # credits: https://github.com/Malfrats/xeuledoc
                 'from': r'https://docs.google.com/(spreadsheets|document|presentation|drawings)/d/(?P<gdoc_id>[\w-]+)',
                 'to': 'https://clients6.google.com/drive/v2beta/files/{gdoc_id}?fields=alternateLink%2CcopyRequiresWriterPermission%2CcreatedDate%2Cdescription%2CdriveId%2CfileSize%2CiconLink%2Cid%2Clabels(starred%2C%20trashed)%2ClastViewedByMeDate%2CmodifiedDate%2Cshared%2CteamDriveId%2CuserPermission(id%2Cname%2CemailAddress%2Cdomain%2Crole%2CadditionalRoles%2CphotoLink%2Ctype%2CwithLink)%2Cpermissions(id%2Cname%2CemailAddress%2Cdomain%2Crole%2CadditionalRoles%2CphotoLink%2Ctype%2CwithLink)%2Cparents(id)%2Ccapabilities(canMoveItemWithinDrive%2CcanMoveItemOutOfDrive%2CcanMoveItemOutOfTeamDrive%2CcanAddChildren%2CcanEdit%2CcanDownload%2CcanComment%2CcanMoveChildrenWithinDrive%2CcanRename%2CcanRemoveChildren%2CcanMoveItemIntoTeamDrive)%2Ckind&supportsTeamDrives=true&enforceSingleParent=true&key=AIzaSyC1eQ1xj69IdTMeii5r7brs3R90eck-m7k',
                 'headers': {"X-Origin": "https://drive.google.com"},
@@ -1130,8 +1138,8 @@ schemes = {
         'flags': ['<meta property="og:url" content="https://tproger.ru/author/'],
         'bs': True,
         'fields': {
-            'fullname': lambda x: x.find('div', {'class': 'author-meta'}).find('h2').contents[0],
-            'image': lambda x: x.find('div', {'class': 'author-meta'}).find('img').get('data-src', ''),
+            'fullname': lambda x: x.find('h1', {'class': 'author-main__header'}).contents[0],
+            'image': lambda x: x.find('div', {'class': 'author-main'}).find('img').get('data-src', ''),
         }
     },
     'Jsfiddle.net': {
