@@ -510,7 +510,7 @@ def test_deviantart():
     assert info.get('website') == 'www.purelymuse.com'
     assert info.get('username') == 'Muse1908'
     assert info.get(
-        'links') == "['https://www.instagram.com/muse_mercier/']"
+        'links') == "['https://www.instagram.com/muse.mercier/']"
     assert info.get('tagline') == 'Nothing worth having is easy...'
 
 
@@ -558,6 +558,7 @@ def test_gravatar():
     assert info.get('fullname') == 'kost BebiX'
     assert info.get('location') == 'Kiev, Ukraine'
     assert info.get('emails') == "['k.bx@ya.ru']"
+    assert info.get('image') == 'https://secure.gravatar.com/avatar/d6ac4c55425d6f9d28db9068dbb49e09'
     assert info.get('links') == "['http://twitter.com/kost_bebix']"
 
 
@@ -791,8 +792,8 @@ def test_xakep():
 def test_tproger():
     info = extract(parse('https://tproger.ru/author/NickPrice/')[0])
 
-    assert info.get('fullname') == 'Никита Прияцелюк, последний центурион'
-    assert info.get('image') == 'https://secure.gravatar.com/avatar/b6c7803b43433349ff84b11093562594?s=90&d=mm&r=g'
+    assert info.get('fullname') == 'Никита Прияцелюк'
+    assert info.get('image').startswith('https://secure.gravatar.com/avatar/b6c7803b43433349ff84b11093562594') == True
 
 
 def test_jsfiddle():
